@@ -3,6 +3,10 @@ xyplot.etm <- function(x, data = NULL, tr.choice = "all", col = c(1, 1, 1), lty
                        conf.int = TRUE, ci.fun = "linear", level = 0.95, ...) {
     if (!inherits(x, "etm"))
         stop("Argument 'x' must be of class 'etm'")
+    ref <- sapply(1:length(x$state.names), function(i) {
+        paste(x$state.names, x$state.names[i])
+    })
+    ref <- matrix(ref)
     if (tr.choice[1] == "all") {
         ufrom <- unique(x$trans$from)
         uto <- unique(x$trans$to)
@@ -14,7 +18,7 @@ xyplot.etm <- function(x, data = NULL, tr.choice = "all", col = c(1, 1, 1), lty
                  paste(x$trans$from, x$trans$to))
         tr.choice <- pos
     }
-    else if (sum(tr.choice %in% rownames(x$cov) == FALSE) > 0)
+    else if (sum(tr.choice %in% ref == FALSE) > 0)
         stop("Argument 'tr.choice' and possible transitions must match")    
     temp <- ci.transfo(x, tr.choice, level, ci.fun)
     for (i in seq_along(temp)) {
